
# Slot: source_file_date


modification date of the source of the schema

URI: [meta:source_file_date](https://w3id.org/biolink/biolinkml/meta/source_file_date)

## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>OPT</sub> [Datetime](Datetime.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
